<?php

namespace Litecms\Buslists\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Buslists\Http\Requests\BuslistsRequest;
use Litecms\Buslists\Interfaces\BuslistsRepositoryInterface;
use Litecms\Buslists\Models\Buslists;

/**
 * Resource controller class for buslists.
 */
class BuslistsResourceController extends BaseController
{

    /**
     * Initialize buslists resource controller.
     *
     * @param type BuslistsRepositoryInterface $buslists
     *
     * @return null
     */
    public function __construct(BuslistsRepositoryInterface $buslists)
    {
        parent::__construct();
        $this->repository = $buslists;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Buslists\Repositories\Criteria\BuslistsResourceCriteria::class);
    }

    /**
     * Display a list of buslists.
     *
     * @return Response
     */
    public function index(BuslistsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Buslists\Repositories\Presenter\BuslistsPresenter::class)
                ->$function();
        }

        $buslists = $this->repository->paginate();

        return $this->response->title(trans('buslists::buslists.names'))
            ->view('buslists::buslists.index', true)
            ->data(compact('buslists'))
            ->output();
    }

    /**
     * Display buslists.
     *
     * @param Request $request
     * @param Model   $buslists
     *
     * @return Response
     */
    public function show(BuslistsRequest $request, Buslists $buslists)
    {

        if ($buslists->exists) {
            $view = 'buslists::buslists.show';
        } else {
            $view = 'buslists::buslists.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('buslists::buslists.name'))
            ->data(compact('buslists'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new buslists.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BuslistsRequest $request)
    {

        $buslists = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('buslists::buslists.name')) 
            ->view('buslists::buslists.create', true) 
            ->data(compact('buslists'))
            ->output();
    }

    /**
     * Create new buslists.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BuslistsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $buslists                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('buslists::buslists.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('buslists/buslists/' . $buslists->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/buslists/buslists'))
                ->redirect();
        }

    }

    /**
     * Show buslists for editing.
     *
     * @param Request $request
     * @param Model   $buslists
     *
     * @return Response
     */
    public function edit(BuslistsRequest $request, Buslists $buslists)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('buslists::buslists.name'))
            ->view('buslists::buslists.edit', true)
            ->data(compact('buslists'))
            ->output();
    }

    /**
     * Update the buslists.
     *
     * @param Request $request
     * @param Model   $buslists
     *
     * @return Response
     */
    public function update(BuslistsRequest $request, Buslists $buslists)
    {
        try {
            $attributes = $request->all();

            $buslists->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('buslists::buslists.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('buslists/buslists/' . $buslists->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('buslists/buslists/' . $buslists->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the buslists.
     *
     * @param Model   $buslists
     *
     * @return Response
     */
    public function destroy(BuslistsRequest $request, Buslists $buslists)
    {
        try {

            $buslists->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('buslists::buslists.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('buslists/buslists/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('buslists/buslists/' . $buslists->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple buslists.
     *
     * @param Model   $buslists
     *
     * @return Response
     */
    public function delete(BuslistsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('buslists::buslists.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('buslists/buslists'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/buslists/buslists'))
                ->redirect();
        }

    }

    /**
     * Restore deleted buslists.
     *
     * @param Model   $buslists
     *
     * @return Response
     */
    public function restore(BuslistsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('buslists::buslists.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/buslists/buslists'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/buslists/buslists/'))
                ->redirect();
        }

    }

}
